==> smtp-0.5.9-004.zip: smtp-0.5.9/out_iq_vcard.c <==
#include "smtp.h"
extern smtpi jtin;


int smtp_out_packets_iq_vcard(smtpp par, char *type)
   {
   int liProcess=0;
   jpacket jp=par->jp;
   char *lcLang;
   xmlnode loQuery, loField;
   smtp_jq loQueue;
   smtp_jq_x loData;


   lcLang=par->lang;

   if (liProcess==0 && j_strcmp(jp->iqns,NS_VCARD)==0 && jp->subtype==JPACKET__GET)
      {
      loQueue=smtp_NewQueueItem(par->tmppool,SMTP_QUEUE_X);
      loData=(smtp_jq_x) loQueue->Data;
      loData->x=out_SetReply(xmlnode_new_tag("iq"),jp->x);
      xmlnode_put_attrib(loData->x,"type","result");
      xmlnode_put_attrib(loQuery=xmlnode_insert_tag(loData->x,"vCard"),"xmlns",NS_VCARD);

      xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"JABBERID"),xmlnode_get_attrib(jp->x,"to"),-1);

      if (jp->to->user==NULL)
         {
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"FN"),smtp_name,-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"URL"),"http://gorila.netlab.cz/jabber.html",-1);

         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"TITLE"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_TITLE),-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"ROLE"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_ROLE),-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"BDAY"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_BDAY),-1); 

         loField=xmlnode_insert_tag(loQuery,"DESC");
         xmlnode_insert_cdata(loField,smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_HISTORY),-1);
         xmlnode_insert_cdata(loField,"\r\nMatthias Wimmer <m@tthias.net>\r\nhttp://devel.amessage.info/smtp-t/\r\n\r\n",-1);
         }

      liProcess=1;
      }


   if (liProcess==1)
      smtp_FlushQueue(par->i, loQueue);

   return liProcess;
   }

==> smtp-0.5.9-016.zip: smtp-0.5.9/out_iq_vcard.c <==
#include "smtp.h"
extern smtpi jtin;


int smtp_out_packets_iq_vcard(smtpp par, char *type)
   {
   int liProcess=0;
   jpacket jp=par->jp;
   char *lcLang;
   xmlnode loQuery, loField;
   smtp_jq loQueue;
   smtp_jq_x loData;


   lcLang=par->lang;

   if (liProcess==0 && j_strcmp(jp->iqns,NS_VCARD)==0 && jp->subtype==JPACKET__GET)
      {
      loQueue=smtp_NewQueueItem(par->tmppool,SMTP_QUEUE_X);
      loData=(smtp_jq_x) loQueue->Data;
      loData->x=out_SetReply(xmlnode_new_tag("iq"),jp->x);
      smtp_PoolsReg(1300, xmlnode_pool(loData->x));

      xmlnode_put_attrib(loData->x,"type","result");
      xmlnode_put_attrib(loQuery=xmlnode_insert_tag(loData->x,"vCard"),"xmlns",NS_VCARD);

      xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"JABBERID"),xmlnode_get_attrib(jp->x,"to"),-1);

      if (jp->to->user==NULL)
         {
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"FN"),smtp_name,-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"URL"),"http://gorila.netlab.cz/jabber.html",-1);

         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"TITLE"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_TITLE),-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"ROLE"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_ROLE),-1);
         xmlnode_insert_cdata(xmlnode_insert_tag(loQuery,"BDAY"),smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_BDAY),-1); 

         loField=xmlnode_insert_tag(loQuery,"DESC");
         xmlnode_insert_cdata(loField,"http://www.jabber.cz/wiki/SMTP_transport (cs)\r\n\r\n",-1);
         xmlnode_insert_cdata(loField,smtp_rc_GetString(par->tmppool,lcLang,SMTP_RC_VCARD_HISTORY),-1);
         xmlnode_insert_cdata(loField,"\r\nMatthias Wimmer <m@tthias.net>\r\nhttp://devel.amessage.info/smtp-t/\r\n\r\n",-1);
         }

      liProcess=1;
      }


   if (liProcess==1)
      smtp_FlushQueue(par->i, loQueue);

   return liProcess;
   }
